# XChainPy2 THORChain client

https://thorchain.org/

> THORChain is a network that facilitates native asset settlement between Bitcoin, Ethereum, BNB Chain, Avalanche, Cosmos Hub, Dogecoin, Bitcoin Cash & Litecoin

> THORChain is secured by its native token, RUNE, which deterministically accrues value as more assets are deposited into the network.

> Anyone can use THORChain to swap native assets between any supported chains or deposit their assets to earn yield from swaps.

### Documentation

👉 https://xchainpy2.readthedocs.io/en/latest/packages/xchainpy2_thorchain.html
